@@ -6,12 +6,12 @@ namespace traits{
 
     template <int RTYPE, template <class> class StoragePolicy>
     struct is_materialized< Vector<RTYPE,StoragePolicy> >{
-        using type = std::true_type ;
+        typedef std::true_type type ;
     } ;
     
     template <int RTYPE, template <class> class StoragePolicy>
     struct is_materialized< Matrix<RTYPE,StoragePolicy> >{
-        using type = std::true_type ;
+        typedef std::true_type type ;
     } ;
     
 }
